@@ -47,7 +47,7 @@ class EicreconRecipe(Recipe):
 
         # cmake command:
         # the  -Wno-dev  flag is to ignore the project developers cmake warnings for policy CMP0075
-        self.config['build_cmd'] = "cmake -w -DCMAKE_INSTALL_PREFIX={install_path} -DCMAKE_CXX_STANDARD={cxx_standard} {source_path}" \
+        self.config['build_cmd'] = "cmake -DCMAKE_INSTALL_PREFIX={install_path} -DCMAKE_CXX_STANDARD={cxx_standard} {source_path}" \
                                    "&& cmake --build . -- -j {build_threads}" \
                                    "&& cmake --build . --target install" \
             .format(**self.config)
